@@ -1,19 +1,5 @@
 # texttable - module for creating simple ASCII tables
-# Copyright (C) 2003-2015 Gerome Fournier <jef(at)foutaise.org>
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+# Copyright (C) 2003-2018 Gerome Fournier <jef(at)foutaise.org>
 
 """module for creating simple ASCII tables
 
@@ -75,8 +61,8 @@ from __future__ import division
 __all__ = ["Texttable", "ArraySizeError"]
 
 __author__ = 'Gerome Fournier <jef(at)foutaise.org>'
-__license__ = 'LGPL'
-__version__ = '1.3.1'
+__license__ = 'MIT'
+__version__ = '1.5.0'
 __credits__ = """\
 Jeff Kowalczyk:
     - textwrap improved import
@@ -191,9 +177,7 @@ class Texttable:
         - if set to 0, size is unlimited, therefore cells won't be wrapped
         """
 
-        if max_width <= 0:
-            max_width = False
-        self._max_width = max_width
+        self.set_max_width(max_width)
         self._precision = 3
 
         self._deco = Texttable.VLINES | Texttable.HLINES | Texttable.BORDER | \
@@ -211,6 +195,16 @@ class Texttable:
         self._row_size = None
         self._header = []
         self._rows = []
+        return self
+
+    def set_max_width(self, max_width):
+        """Set the maximum width of the table
+
+        - max_width is an integer, specifying the maximum width of the table
+        - if set to 0, size is unlimited, therefore cells won't be wrapped
+        """
+        self._max_width = max_width if max_width > 0 else False
+        return self
 
     def set_chars(self, array):
         """Set the characters used to draw lines between rows and columns
@@ -229,6 +223,7 @@ class Texttable:
         array = [ x[:1] for x in [ str(s) for s in array ] ]
         (self._char_horiz, self._char_vert,
             self._char_corner, self._char_header) = array
+        return self
 
     def set_deco(self, deco):
         """Set the table decoration
@@ -248,6 +243,21 @@ class Texttable:
         """
 
         self._deco = deco
+        return self
+
+    def set_header_align(self, array):
+        """Set the desired header alignment
+
+        - the elements of the array should be either "l", "c" or "r":
+
+            * "l": column flushed left
+            * "c": column centered
+            * "r": column flushed right
+        """
+
+        self._check_row_size(array)
+        self._header_align = array
+        return self
 
     def set_cols_align(self, array):
         """Set the desired columns alignment
@@ -261,6 +271,7 @@ class Texttable:
 
         self._check_row_size(array)
         self._align = array
+        return self
 
     def set_cols_valign(self, array):
         """Set the desired columns vertical alignment
@@ -274,6 +285,7 @@ class Texttable:
 
         self._check_row_size(array)
         self._valign = array
+        return self
 
     def set_cols_dtype(self, array):
         """Set the desired columns datatype for the cols.
@@ -293,6 +305,7 @@ class Texttable:
 
         self._check_row_size(array)
         self._dtype = array
+        return self
 
     def set_cols_width(self, array):
         """Set the desired columns width
@@ -312,6 +325,7 @@ class Texttable:
             sys.stderr.write("Wrong argument in column width specification\n")
             raise
         self._width = array
+        return self
 
     def set_precision(self, width):
         """Set the desired precision for float/exponential formats
@@ -324,6 +338,7 @@ class Texttable:
         if not type(width) is int or width < 0:
             raise ValueError('width must be an integer greater then 0')
         self._precision = width
+        return self
 
     def header(self, array):
         """Specify the header of the table
@@ -331,6 +346,7 @@ class Texttable:
 
         self._check_row_size(array)
         self._header = list(map(obj2unicode, array))
+        return self
 
     def add_row(self, array):
         """Add a row in the rows stack
@@ -347,6 +363,7 @@ class Texttable:
         for i, x in enumerate(array):
             cells.append(self._str(i, x))
         self._rows.append(cells)
+        return self
 
     def add_rows(self, rows, header=True):
         """Add several rows in the rows stack
@@ -367,6 +384,7 @@ class Texttable:
                 rows = rows[1:]
         for row in rows:
             self.add_row(row)
+        return self
 
     def draw(self):
         """Draw the table
@@ -609,6 +627,8 @@ class Texttable:
         """Check if alignment has been specified, set default one if not
         """
 
+        if not hasattr(self, "_header_align"):
+            self._header_align = ["c"] * self._row_size
         if not hasattr(self, "_align"):
             self._align = ["l"] * self._row_size
         if not hasattr(self, "_valign"):
@@ -632,7 +652,7 @@ class Texttable:
                 cell_line = cell[i]
                 fill = width - len(cell_line)
                 if isheader:
-                    align = "c"
+                    align = self._header_align[length - 1]
                 if align == "r":
                     out += fill * space + cell_line
                 elif align == "c":
